@@ -42,10 +42,10 @@ import lombok.EqualsAndHashCode;
 import lombok.Getter;
 import lombok.Setter;
 import lombok.ToString;
-import org.hibernate.validator.constraints.Length;
 
 import javax.validation.constraints.Email;
 import javax.validation.constraints.NotNull;
+import javax.validation.constraints.Size;
 import java.time.Instant;
 
 /**
@@ -68,12 +68,12 @@ public class SubrogationDto extends IdDto {
     private Instant date;
 
     @NotNull
-    @Length(min = 4, max = 100)
+    @Size(min = 4, max = 100)
     @Email
     private String surrogate;
 
     @NotNull
-    @Length(min = 4, max = 100)
+    @Size(min = 4, max = 100)
     @Email
     private String superUser;
 
